Welcome to Diofant's documentation!
===================================

`Diofant <https://diofant.readthedocs.io/en/latest/>`_ is a Python library for symbolic mathematics.
If you are new to Diofant, start with the :ref:`Tutorial <tutorial>`.

This is the central page for all of Diofant's documentation.


Contents:

.. toctree::
   :maxdepth: 2

   install.rst
   tutorial/index.rst
   modules/index.rst
   internals/index.rst
   guide.rst
   aboutus.rst
   release/index.rst
